==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/Notes/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'ERR_DELETE_RECORD' => 'You must specify a record number to delete the account.',
	'LBL_ACCOUNT_ID' => 'Account ID:',
	'LBL_CASE_ID' => 'Case ID:',
	'LBL_CLOSE' => 'Close:',
	'LBL_COLON' => ':',
	'LBL_CONTACT_ID' => 'Contact ID:',
	'LBL_CONTACT_NAME' => 'Contact:',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Notes',
	'LBL_DESCRIPTION' => 'Note',
	'LBL_EMAIL_ADDRESS' => 'Email Address:',
    'LBL_EMAIL_ATTACHMENT' => 'Email Attachment',
	'LBL_FILE_MIME_TYPE' => 'Mime Type',
	'LBL_FILE_URL' => 'File URL',
	'LBL_FILENAME' => 'Attachment:',
	'LBL_LEAD_ID' => 'Lead ID:',
	'LBL_LIST_CONTACT_NAME' => 'Contact',
	'LBL_LIST_DATE_MODIFIED' => 'Last Modified',
	'LBL_LIST_FILENAME' => 'Attachment',
	'LBL_LIST_FORM_TITLE' => 'Note List',
	'LBL_LIST_RELATED_TO' => 'Related To',
	'LBL_LIST_SUBJECT' => 'Subject',
	'LBL_LIST_STATUS' => 'Status',
	'LBL_LIST_CONTACT' => 'Contact',
	'LBL_MODULE_NAME' => 'Notes',
	'LBL_MODULE_TITLE' => 'Notes: Home',
	'LBL_NEW_FORM_TITLE' => 'Create Note or Attachment',
	'LBL_NOTE_STATUS' => 'Note',
	'LBL_NOTE_SUBJECT' => 'Note Subject:',
	'LBL_NOTES_SUBPANEL_TITLE' => 'Attachments',
	'LBL_NOTE' => 'Note:',
	'LBL_OPPORTUNITY_ID' => 'Opportunity ID:',
	'LBL_PARENT_ID' => 'Parent ID:',
	'LBL_PARENT_TYPE' => 'Parent Type',
	'LBL_PHONE' => 'Phone:',
	'LBL_PORTAL_FLAG' => 'Display in Portal?',
	'LBL_EMBED_FLAG' => 'Embed in email?',
	'LBL_PRODUCT_ID' => 'Product ID:',
	'LBL_QUOTE_ID' => 'Quote ID:',
	'LBL_RELATED_TO' => 'Related To:',
	'LBL_SEARCH_FORM_TITLE' => 'Note Search',
	'LBL_STATUS' => 'Status',
	'LBL_SUBJECT' => 'Subject:',
	'LNK_CALL_LIST' => 'Calls',
	'LNK_EMAIL_LIST' => 'Emails',
	'LNK_IMPORT_NOTES' => 'Import Notes',
	'LNK_MEETING_LIST' => 'Meetings',
	'LNK_NEW_CALL' => 'Schedule Call',
	'LNK_NEW_EMAIL' => 'Archive Email',
	'LNK_NEW_MEETING' => 'Schedule Meeting',
	'LNK_NEW_NOTE' => 'Create Note or Attachment',
	'LNK_NEW_TASK' => 'Create Task',
	'LNK_NOTE_LIST' => 'Notes',
	'LNK_TASK_LIST' => 'Tasks',
	'LNK_VIEW_CALENDAR' => 'Today',
	'LBL_MEMBER_OF' => 'Member of:',
	'LBL_LIST_ASSIGNED_TO_NAME' => 'Assigned User',
    'LBL_REMOVING_ATTACHMENT'=>'Removing attachment...',
    'ERR_REMOVING_ATTACHMENT'=>'Failed to remove attachment...',
    'LBL_CREATED_BY'=>'Created By',
    'LBL_MODIFIED_BY'=>'Modified By',
    'LBL_SEND_ANYWAYS'=> 'This email has no subject.  Send/save anyway?',
	'LBL_LIST_EDIT_BUTTON' => 'Edit',
	'LBL_ACTIVITIES_REPORTS' => 'Activities Report',    
	
);

?>

==> SugarCE-6.2.0.zip: SugarCE-Full-6.2.0/modules/Notes/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'ERR_DELETE_RECORD' => 'You must specify a record number to delete the account.',
	'LBL_ACCOUNT_ID' => 'Account ID:',
	'LBL_CASE_ID' => 'Case ID:',
	'LBL_CLOSE' => 'Close:',
	'LBL_COLON' => ':',
	'LBL_CONTACT_ID' => 'Contact ID:',
	'LBL_CONTACT_NAME' => 'Contact:',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Notes',
	'LBL_DESCRIPTION' => 'Note',
	'LBL_EMAIL_ADDRESS' => 'Email Address:',
    'LBL_EMAIL_ATTACHMENT' => 'Email Attachment',
	'LBL_FILE_MIME_TYPE' => 'Mime Type',
	'LBL_FILE_URL' => 'File URL',
	'LBL_FILENAME' => 'Attachment:',
	'LBL_LEAD_ID' => 'Lead ID:',
	'LBL_LIST_CONTACT_NAME' => 'Contact',
	'LBL_LIST_DATE_MODIFIED' => 'Last Modified',
	'LBL_LIST_FILENAME' => 'Attachment',
	'LBL_LIST_FORM_TITLE' => 'Note List',
	'LBL_LIST_RELATED_TO' => 'Related To',
	'LBL_LIST_SUBJECT' => 'Subject',
	'LBL_LIST_STATUS' => 'Status',
	'LBL_LIST_CONTACT' => 'Contact',
	'LBL_MODULE_NAME' => 'Notes',
	'LBL_MODULE_TITLE' => 'Notes: Home',
	'LBL_NEW_FORM_TITLE' => 'Create Note or Add Attachment',
	'LBL_NOTE_STATUS' => 'Note',
	'LBL_NOTE_SUBJECT' => 'Subject:',
	'LBL_NOTES_SUBPANEL_TITLE' => 'Attachments',
	'LBL_NOTE' => 'Note:',
	'LBL_OPPORTUNITY_ID' => 'Opportunity ID:',
	'LBL_PARENT_ID' => 'Parent ID:',
	'LBL_PARENT_TYPE' => 'Parent Type',
	'LBL_PHONE' => 'Phone:',
	'LBL_PORTAL_FLAG' => 'Display in Portal?',
	'LBL_EMBED_FLAG' => 'Embed in email?',
	'LBL_PRODUCT_ID' => 'Product ID:',
	'LBL_QUOTE_ID' => 'Quote ID:',
	'LBL_RELATED_TO' => 'Related To:',
	'LBL_SEARCH_FORM_TITLE' => 'Note Search',
	'LBL_STATUS' => 'Status',
	'LBL_SUBJECT' => 'Subject:',
	'LNK_IMPORT_NOTES' => 'Import Notes',
	'LNK_NEW_NOTE' => 'Create Note or Attachment',
	'LNK_NOTE_LIST' => 'View Notes',
	'LNK_IMPORT_NOTES' => 'Import Notes',
	'LBL_MEMBER_OF' => 'Member of:',
	'LBL_LIST_ASSIGNED_TO_NAME' => 'Assigned User',
    'LBL_REMOVING_ATTACHMENT'=>'Removing attachment...',
    'ERR_REMOVING_ATTACHMENT'=>'Failed to remove attachment...',
    'LBL_CREATED_BY'=>'Created By',
    'LBL_MODIFIED_BY'=>'Modified By',
    'LBL_SEND_ANYWAYS'=> 'This email has no subject.  Send/save anyway?',
	'LBL_LIST_EDIT_BUTTON' => 'Edit',
	'LBL_ACTIVITIES_REPORTS' => 'Activities Report',
	'LBL_PANEL_DETAILS' => 'Details',
	'LBL_NOTE_INFORMATION' => 'Note Overview',
	'LBL_MY_NOTES_DASHLETNAME' => 'My Notes',
);

?>
